@@ -43,19 +43,14 @@ static const GdkColor default_baize_color = { 0, 0 /* red */, 0x5000 /* green */
 #endif
 
 #define DEFAULT_SHOW_TOOLTIPS (FALSE)
-#define DEFAULT_SHOW_STATUS_MESSAGES (TRUE)
+#define DEFAULT_SHOW_STATUS_MESSAGES (FALSE)
 
 struct _ArStylePrivate
 {
   ArCardTheme* card_theme;
 
-#ifdef HAVE_CLUTTER
-  ClutterColor selection_color;
-  ClutterColor baize_color;
-#else
   GdkColor selection_color;
   GdkColor baize_color;
-#endif
 
   double card_slot_ratio;
   double card_overhang;
@@ -84,16 +79,9 @@ struct _ArStylePrivate
   guint show_highlight          : 1;
   guint show_seleccion          : 1;
 
-#ifndef HAVE_CLUTTER
   guint pixbuf_drawing          : 1;
-#endif
 };
 
-#ifdef HAVE_CLUTTER
-void _ar_clutter_color_from_gdk_color (ClutterColor *clutter_color,
-                                       const GdkColor *gdk_color);
-#endif
-
 G_END_DECLS
 
 #endif /* __AR_STYLE_PRIVATE_H__ */
