@@ -54,14 +54,7 @@
 #include <libgames-support/games-settings.h>
 #endif
 
-#ifdef HAVE_CLUTTER
-#include "ar-clutter-embed.h"
-#include "ar-style.h"
-#include "baize.h"
-#include "board.h"
-#else
 #include "board-noclutter.h"
-#endif
 
 #include "ar-card-theme.h"
 #include "ar-card-themes.h"
@@ -131,13 +124,7 @@ struct _AisleriotWindowPrivate
 {
   AisleriotGame *game;
   ArStyle *board_style;
-#ifdef HAVE_CLUTTER
-  ArClutterEmbed *board;
-  ClutterActor *baize_actor;
-  ClutterActor *board_actor;
-#else
   AisleriotBoard *board;
-#endif
 
   ArCardThemes *theme_manager;
   ArCardTheme *theme;
@@ -379,11 +366,7 @@ undo_cb (GtkAction *action,
   AisleriotWindowPrivate *priv = window->priv;
 
   /* If a move is in progress, cancel it before changing the game! */
-#ifdef HAVE_CLUTTER
-  aisleriot_board_abort_move (AISLERIOT_BOARD (priv->board_actor));
-#else
   aisleriot_board_abort_move (priv->board);
-#endif
 
   aisleriot_game_undo_move (priv->game);
 }
@@ -394,11 +377,7 @@ redo_cb (GtkAction *action,
 {
   AisleriotWindowPrivate *priv = window->priv;
 
-#ifdef HAVE_CLUTTER
-  aisleriot_board_abort_move (AISLERIOT_BOARD (priv->board_actor));
-#else
   aisleriot_board_abort_move (priv->board);
-#endif
 
   aisleriot_game_redo_move (priv->game);
 }
@@ -851,8 +830,8 @@ debug_choose_seed_cb (GtkAction *action,
 }
 
 static void
-debug_tweak_cb (GtkAction *action,
-                AisleriotWindow *window)
+debug_tweak_style_cb (GtkAction *action,
+                      AisleriotWindow *window)
 {
   AisleriotWindowPrivate *priv = window->priv;
   GObject *object;
@@ -869,6 +848,24 @@ debug_tweak_cb (GtkAction *action,
   gtk_window_present (GTK_WINDOW (prop_editor));
 }
 
+static void
+debug_tweak_settings_cb (GtkAction *action,
+                         AisleriotWindow *window)
+{
+  GObject *object;
+  GType type;
+  GtkWidget *prop_editor;
+
+  object = G_OBJECT (gtk_widget_get_settings (GTK_WIDGET (window)));
+  type = G_OBJECT_TYPE (object);
+
+  g_assert (object != NULL);
+
+  prop_editor = create_prop_editor (object, type);
+  gtk_window_set_transient_for (GTK_WINDOW (prop_editor), GTK_WINDOW (window));
+  gtk_window_present (GTK_WINDOW (prop_editor));
+}
+
 #endif /* ENABLE_DEBUG_UI */
 
 static void
@@ -1014,24 +1011,6 @@ sound_toggle_cb (GtkToggleAction *action,
 
 #endif /* ENABLE_SOUND */
 
-#ifdef HAVE_CLUTTER
-
-static void
-animations_toggle_cb (GtkToggleAction *action,
-                      AisleriotWindow *window)
-{
-  AisleriotWindowPrivate *priv = window->priv;
-  gboolean enabled;
-
-  enabled = gtk_toggle_action_get_active (action);
-
-  ar_style_set_enable_animations (priv->board_style, enabled);
-  
-  games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_ANIMATIONS), enabled);
-}
-
-#endif /* HAVE_CLUTTER */
-
 static void
 show_hint_cb (GtkAction *action,
               AisleriotWindow *window)
@@ -1922,7 +1901,7 @@ game_exception_cb (AisleriotGame *game,
   gtk_widget_show (dialog);
 }
 
-#if defined(HAVE_CLUTTER) || (defined(ENABLE_SOUND) && GTK_CHECK_VERSION (2, 14, 0))
+#if defined(ENABLE_SOUND) && GTK_CHECK_VERSION (2, 14, 0)
 
 static void
 settings_changed_cb (GtkSettings *settings,
@@ -1939,23 +1918,12 @@ settings_changed_cb (GtkSettings *settings,
   else
     name = NULL;
 
-#ifdef HAVE_CLUTTER
-  if (name == NULL || strcmp (name, "gtk-enable-animations") == 0) {
-    g_object_get (settings, "gtk-enable-animations", &enabled, NULL);
-
-    action = gtk_action_group_get_action (priv->action_group, "Animations");
-    gtk_action_set_visible (action, enabled);
-  }
-#endif /* HAVE_CLUTTER */
-
-#if defined(ENABLE_SOUND) && GTK_CHECK_VERSION (2, 14, 0)
   if (name == NULL || strcmp (name, "gtk-enable-event-sounds") == 0) {
     g_object_get (settings, "gtk-enable-event-sounds", &enabled, NULL);
 
     action = gtk_action_group_get_action (priv->action_group, "Sound");
     gtk_action_set_visible (action, enabled);
   }
-#endif /* ENABLE_SOUND && GTK >= 2.14 */
 }
 
 static void
@@ -1983,17 +1951,11 @@ screen_changed_cb (GtkWidget *widget,
 
   settings = gtk_widget_get_settings (widget);
   settings_changed_cb (settings, NULL, window);
-#ifdef HAVE_CLUTTER
-  g_signal_connect (settings, "notify::gtk-enable-animations",
-                    G_CALLBACK (settings_changed_cb), window);
-#endif
-#if defined (ENABLE_SOUND) && GTK_CHECK_VERSION (2, 14, 0)
   g_signal_connect (settings, "notify::gtk-enable-event-sounds",
                     G_CALLBACK (settings_changed_cb), window);
-#endif
 }
 
-#endif /* HAVE_CLUTTER || ENABLE_SOUND && GTK+ >= 2.14.0 */
+#endif /* ENABLE_SOUND && GTK+ >= 2.14.0 */
 
 /*
  * aisleriot_window_set_freecell_mode:
@@ -2043,37 +2005,6 @@ board_status_message_cb (AisleriotBoard *board,
 
 #endif /* !HAVE_HILDON */
 
-#ifdef HAVE_CLUTTER
-
-static void
-board_cursor_cb (AisleriotBoard *board,
-                 int cursor_type,
-                 ArClutterEmbed *embed)
-{
-  ar_clutter_embed_set_cursor (embed, (ArCursorType) cursor_type);
-}
-
-static void
-board_error_bell_cb (AisleriotBoard *board,
-                     ArClutterEmbed *embed)
-{
-#if GTK_CHECK_VERSION (2, 12, 0) || (defined (HAVE_HILDON) && !defined(HAVE_MAEMO_3))
-  gtk_widget_error_bell (GTK_WIDGET (embed));
-#endif
-}
-
-static void
-embed_size_allocate_cb (ArClutterEmbed *embed,
-                        GtkAllocation *allocation,
-                        AisleriotWindow *window)
-{
-  AisleriotWindowPrivate *priv = window->priv;
-
-  clutter_actor_set_size (priv->board_actor, allocation->width, allocation->height);
-}
-
-#endif /* HAVE_CLUTTER */
-
 /* Class implementation */
 
 #ifdef HAVE_HILDON
@@ -2268,7 +2199,9 @@ aisleriot_window_init (AisleriotWindow *window)
       G_CALLBACK (debug_game_prev) },
 #endif /* !HAVE_HILDON */
     { "DebugTweakStyle", NULL, "_Tweak Style", NULL, NULL,
-      G_CALLBACK (debug_tweak_cb) },
+      G_CALLBACK (debug_tweak_style_cb) },
+    { "DebugTweakSettings", NULL, "_Tweak GtkSettings", NULL, NULL,
+      G_CALLBACK (debug_tweak_settings_cb) },
 #endif /* ENABLE_DEBUG_UI */
 
     /* Accel actions */
@@ -2304,12 +2237,6 @@ aisleriot_window_init (AisleriotWindow *window)
       G_CALLBACK (sound_toggle_cb),
       FALSE /* not active by default */ },
 #endif /* ENABLE_SOUND */
-#ifdef HAVE_CLUTTER
-   { "Animations", NULL, N_("_Animations"), NULL,
-      ACTION_TOOLTIP (N_("Whether or not to animate card moves")),
-      G_CALLBACK (animations_toggle_cb),
-      FALSE /* not active by default */ },
-#endif /* HAVE_CLUTTER */
   };
 
   static const char names[][16] = {
@@ -2368,7 +2295,8 @@ aisleriot_window_init (AisleriotWindow *window)
         "<menu action='DebugMenu'>"
           "<menuitem action='DebugChooseSeed'/>"
           "<menuitem action='DebugTweakStyle'/>"
-        "</menu>"
+          "<menuitem action='DebugTweakSettings'/>"
+          "</menu>"
 #endif /* ENABLE_DEBUG_UI */
         "<menuitem action='CloseWindow'/>"
       "</popup>"
@@ -2405,9 +2333,6 @@ aisleriot_window_init (AisleriotWindow *window)
           "<menuitem action='ClickToMove'/>"
 #ifdef ENABLE_SOUND
           "<menuitem action='Sound'/>"
-#endif
-#ifdef HAVE_CLUTTER
-          "<menuitem action='Animations'/>"
 #endif
         "</menu>"
         "<menu action='OptionsMenu'/>"
@@ -2419,6 +2344,7 @@ aisleriot_window_init (AisleriotWindow *window)
 #ifdef ENABLE_DEBUG_UI
         "<menu action='DebugMenu'>"
           "<menuitem action='DebugTweakStyle'/>"
+          "<menuitem action='DebugTweakSettings'/>"
           "<separator/>"
           "<menuitem action='DebugChooseSeed'/>"
           "<menuitem action='DebugMoveNextScreen'/>"
@@ -2472,9 +2398,6 @@ aisleriot_window_init (AisleriotWindow *window)
   GtkStatusbar *statusbar;
   GtkWidget *statusbar_hbox, *label, *time_box;
 #endif
-#ifdef HAVE_CLUTTER
-  ClutterContainer *stage;
-#endif
 
   g_assert (G_N_ELEMENTS (names) == LAST_ACTION);
 
@@ -2488,34 +2411,7 @@ aisleriot_window_init (AisleriotWindow *window)
 
   priv->board_style = ar_style_new ();
 
-#ifdef HAVE_CLUTTER
-  priv->board = ar_clutter_embed_new (priv->board_style);
-
-  priv->baize_actor = aisleriot_baize_new ();
-
-  stage = CLUTTER_CONTAINER (gtk_clutter_embed_get_stage (GTK_CLUTTER_EMBED (priv->board)));
-  clutter_container_add (stage, priv->baize_actor, NULL);
-  /* FIXMEchpe: how to ensure this is ALWAYS the lowest actor? */
-  clutter_actor_lower_bottom (priv->baize_actor);
-
-  priv->board_actor = aisleriot_board_new (priv->board_style, priv->game);
-  clutter_container_add (stage, priv->board_actor, NULL);
-
-  /* FIXMEchpe */
-  clutter_stage_set_key_focus (CLUTTER_STAGE (stage), priv->board_actor);
-
-  g_signal_connect_after (priv->board, "size-allocate",
-                          G_CALLBACK (embed_size_allocate_cb), window);
-
-  g_signal_connect (priv->board_actor, "request-cursor",
-                    G_CALLBACK (board_cursor_cb), priv->board);
-  g_signal_connect (priv->board_actor, "error-bell",
-                    G_CALLBACK (board_error_bell_cb), priv->board);
-
-  /* FIXMEchpe: unref baize & board_actor here? */
-#else
   priv->board = AISLERIOT_BOARD (aisleriot_board_new (priv->board_style, priv->game));
-#endif /* HAVE_CLUTTER */
 
   theme_name = games_conf_get_string (NULL, aisleriot_conf_get_key (CONF_THEME), NULL);
   theme = ar_card_themes_get_theme_by_name (priv->theme_manager, theme_name);
@@ -2567,13 +2463,8 @@ aisleriot_window_init (AisleriotWindow *window)
 
   priv->game_message_id = gtk_statusbar_get_context_id (priv->statusbar, "board-message");
 
-#ifdef HAVE_CLUTTER
-  g_signal_connect (priv->board_actor, "status-message",
-                    G_CALLBACK (board_status_message_cb), window);
-#else
   g_signal_connect (priv->board, "status-message",
                     G_CALLBACK (board_status_message_cb), window);
-#endif
 
 #if GTK_CHECK_VERSION (2, 91, 0)
   gtk_window_set_has_resize_grip (GTK_WINDOW (window), TRUE);
@@ -2645,6 +2536,11 @@ aisleriot_window_init (AisleriotWindow *window)
   priv->main_menu = gtk_ui_manager_get_widget (priv->ui_manager, MAIN_MENU_UI_PATH);
   priv->toolbar = gtk_ui_manager_get_widget (priv->ui_manager, TOOLBAR_UI_PATH);
 
+#if GTK_CHECK_VERSION (3, 0, 3)
+  gtk_style_context_add_class (gtk_widget_get_style_context (priv->toolbar),
+                               GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
+#endif
+
   /* Defer building the card themes menu until its parent's menu is opened */
 #ifdef HAVE_HILDON
   /* FIXMEchpe check this works! */
@@ -2715,19 +2611,12 @@ aisleriot_window_init (AisleriotWindow *window)
 
   set_fullscreen_actions (window, FALSE);
 
-#ifdef HAVE_CLUTTER
-  action = gtk_action_group_get_action (priv->action_group, "Animations");
-  gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
-                                games_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_ANIMATIONS), NULL));
-
-#endif /* HAVE_CLUTTER */
-
-#if defined(HAVE_CLUTTER) || (defined(ENABLE_SOUND) && GTK_CHECK_VERSION (2, 14, 0))
+#if defined(ENABLE_SOUND) && GTK_CHECK_VERSION (2, 14, 0)
   /* Set the action visibility and listen for animation and sound mode changes */
   screen_changed_cb (GTK_WIDGET (window), NULL, window);
   g_signal_connect (window, "screen-changed",
                     G_CALLBACK (screen_changed_cb), window);
-#endif /* HAVE_CLUTTER || ENABLE_SOUND && GTK+ >= 2.14.0 */
+#endif /* ENABLE_SOUND && GTK+ >= 2.14.0 */
 
   /* Now set up the widgets */
   main_vbox = gtk_vbox_new (FALSE, 0);
@@ -2813,12 +2702,6 @@ aisleriot_window_dispose (GObject *object)
   AisleriotWindow *window = AISLERIOT_WINDOW (object);
   AisleriotWindowPrivate *priv = window->priv;
   
-#ifdef HAVE_CLUTTER
-  g_signal_handlers_disconnect_by_func (gtk_widget_get_settings (GTK_WIDGET (window)),
-                                        G_CALLBACK (settings_changed_cb),
-                                        window);
-#endif /* HAVE_CLUTTER */
-
 #ifndef HAVE_HILDON
   if (priv->hint_dialog) {
     gtk_widget_destroy (priv->hint_dialog);
@@ -2859,10 +2742,6 @@ aisleriot_window_finalize (GObject *object)
   AisleriotWindow *window = AISLERIOT_WINDOW (object);
   AisleriotWindowPrivate *priv = window->priv;
 
-#ifdef HAVE_CLUTTER
-  g_object_unref (priv->board_style);
-#endif /* HAVE_CLUTTER */
-
   if (priv->theme) {
     g_object_unref (priv->theme);
   }
