@@ -35,7 +35,8 @@
 #include "games-setgid-io.h"
 #endif
 
-struct _GamesScoresBackendPrivate {
+struct GamesScoresBackendPrivate {
+  GList *scores_list;
   GamesScoreStyle style;
   time_t timestamp;
   gchar *filename;
@@ -69,29 +70,29 @@ static void
 games_scores_backend_init (GamesScoresBackend * backend)
 {
   backend->priv = G_TYPE_INSTANCE_GET_PRIVATE (backend,
-					       GAMES_TYPE_SCORES_BACKEND,
-					       GamesScoresBackendPrivate);
+                                               GAMES_TYPE_SCORES_BACKEND,
+                                               GamesScoresBackendPrivate);
 }
 
 GamesScoresBackend *
 games_scores_backend_new (GamesScoreStyle style,
-			  char *base_name,
+                          char *base_name,
                           char *name)
 {
   GamesScoresBackend *backend;
   gchar *fullname;
 
   backend = GAMES_SCORES_BACKEND (g_object_new (GAMES_TYPE_SCORES_BACKEND,
-						NULL));
+                                                NULL));
 
-  if (name[0] == '\0')		/* Name is "" */
+  if (name[0] == '\0')                /* Name is "" */
     fullname = g_strjoin (".", base_name, "scores", NULL);
   else
     fullname = g_strjoin (".", base_name, name, "scores", NULL);
 
   backend->priv->timestamp = 0;
   backend->priv->style = style;
-  backend->scores_list = NULL;
+  backend->priv->scores_list = NULL;
   backend->priv->filename = g_build_filename (games_runtime_get_directory (GAMES_RUNTIME_SCORES_DIRECTORY),
                                               fullname, NULL);
   g_free (fullname);
@@ -115,7 +116,7 @@ games_scores_backend_get_lock (GamesScoresBackend * self)
     /* Assume we already have the lock and rewind the file to
      * the beginning. */
     setgid_io_seek (self->priv->fd, 0, SEEK_SET);
-    return TRUE;		/* Assume we already have the lock. */
+    return TRUE;                /* Assume we already have the lock. */
   }
 
   self->priv->fd = setgid_io_open (self->priv->filename, O_RDWR);
@@ -152,9 +153,16 @@ games_scores_backend_release_lock (GamesScoresBackend * self)
 
 #endif /* ENABLE_SETGID */
 
-/* You can alter the list returned by this function, but you must
+/**
+ * games_scores_backend_get_scores:
+ * @self: the backend to get the scores from
+ * 
+ * You can alter the list returned by this function, but you must
  * make sure you set it again with the _set_scores method or discard it
- * with with the _discard_scores method. Otherwise deadlocks will ensue. */
+ * with with the _discard_scores method. Otherwise deadlocks will ensue.
+ *
+ * Return value: (transfer none) (allow-none) (element-type GnomeGamesSupport.Score): The list of scores
+ */
 GList *
 games_scores_backend_get_scores (GamesScoresBackend * self)
 {
@@ -177,17 +185,17 @@ games_scores_backend_get_scores (GamesScoresBackend * self)
   if (error != 0)
     return NULL;
 
-  if ((info.st_mtime > self->priv->timestamp) || (self->scores_list == NULL)) {
+  if ((info.st_mtime > self->priv->timestamp) || (self->priv->scores_list == NULL)) {
     self->priv->timestamp = info.st_mtime;
 
     /* Dump the old list of scores. */
-    t = self->scores_list;
+    t = self->priv->scores_list;
     while (t != NULL) {
-      games_score_destroy ((GamesScore *) t->data);
+      g_object_unref (t->data);
       t = g_list_next (t);
     }
-    g_list_free (self->scores_list);
-    self->scores_list = NULL;
+    g_list_free (self->priv->scores_list);
+    self->priv->scores_list = NULL;
 
     /* Lock the file and get the list. */
     if (!games_scores_backend_get_lock (self))
@@ -205,9 +213,9 @@ games_scores_backend_get_scores (GamesScoresBackend * self)
       target -= length;
       length = setgid_io_read (self->priv->fd, buffer, info.st_size);
       if (length == -1) {
-	games_scores_backend_release_lock (self);
-	g_free (buffer);
-	return NULL;
+        games_scores_backend_release_lock (self);
+        g_free (buffer);
+        return NULL;
       }
     } while (length < target);
 
@@ -224,30 +232,29 @@ games_scores_backend_get_scores (GamesScoresBackend * self)
       *eol++ = '\0';
       timestr = strchr (scorestr, ' ');
       if (timestr == NULL)
-	break;
+        break;
       *timestr++ = '\0';
       namestr = strchr (timestr, ' ');
       if (namestr == NULL)
-	break;
+        break;
       *namestr++ = '\0';
       /* At this point we have three strings, all null terminated. All
        * part of the original buffer. */
-      newscore = games_score_new ();
-      newscore->name = g_strdup (namestr);
-      newscore->time = g_ascii_strtoull (timestr, NULL, 10);
       switch (self->priv->style) {
       case GAMES_SCORES_STYLE_PLAIN_DESCENDING:
       case GAMES_SCORES_STYLE_PLAIN_ASCENDING:
-	newscore->value.plain = g_ascii_strtod (scorestr, NULL);
-	break;
+        newscore = games_score_new_plain (g_ascii_strtod (scorestr, NULL));
+        break;
       case GAMES_SCORES_STYLE_TIME_DESCENDING:
       case GAMES_SCORES_STYLE_TIME_ASCENDING:
-	newscore->value.time_double = g_ascii_strtod (scorestr, NULL);
-	break;
+        newscore = games_score_new_time (g_ascii_strtod (scorestr, NULL));
+        break;
       default:
         g_assert_not_reached ();
       }
-      self->scores_list = g_list_append (self->scores_list, newscore);
+      games_score_set_name (newscore, namestr);
+      games_score_set_time (newscore, g_ascii_strtoull (timestr, NULL, 10));
+      self->priv->scores_list = g_list_append (self->priv->scores_list, newscore);
       /* Setup again for the next time around. */
       scorestr = eol;
       eol = strchr (eol, '\n');
@@ -258,7 +265,7 @@ games_scores_backend_get_scores (GamesScoresBackend * self)
 
   /* FIXME: Sort the scores! We shouldn't rely on the file being sorted. */
 
-  return self->scores_list;
+  return self->priv->scores_list;
 #else
   return NULL;
 #endif /* ENABLE_SETGID */
@@ -277,34 +284,34 @@ games_scores_backend_set_scores (GamesScoresBackend * self, GList * list)
   if (!games_scores_backend_get_lock (self))
     return FALSE;
 
-  self->scores_list = list;
+  self->priv->scores_list = list;
 
   s = list;
   while (s != NULL) {
     gdouble rscore;
     guint64 rtime;
-    gchar *rname;
+    const gchar *rname;
 
     d = (GamesScore *) s->data;
     rscore = 0.0;
     switch (self->priv->style) {
     case GAMES_SCORES_STYLE_PLAIN_DESCENDING:
     case GAMES_SCORES_STYLE_PLAIN_ASCENDING:
-      rscore = d->value.plain;
+      rscore = games_score_get_value_as_plain (d);
       break;
     case GAMES_SCORES_STYLE_TIME_DESCENDING:
     case GAMES_SCORES_STYLE_TIME_ASCENDING:
-      rscore = d->value.time_double;
+      rscore = games_score_get_value_as_time(d);
       break;
     default:
       g_assert_not_reached ();
     }
-    rtime = d->time;
-    rname = d->name;
+    rtime = games_score_get_time (d);
+    rname = games_score_get_name(d);
 
     buffer = g_strdup_printf ("%s %"G_GUINT64_FORMAT" %s\n",
-			      g_ascii_dtostr (dtostrbuf, sizeof (dtostrbuf),
-					      rscore), rtime, rname);
+                              g_ascii_dtostr (dtostrbuf, sizeof (dtostrbuf),
+                                              rscore), rtime, rname);
     setgid_io_write (self->priv->fd, buffer, strlen (buffer));
     output_length += strlen (buffer);
     /* Ignore any errors and blunder on. */
